@@ -16,7 +16,7 @@ import conftest
 
 def test_run(experiment):
     num_samples = num_workers = 5
-    results = experiment.run(conftest.exec_func, num_samples, num_workers, verbose=True)
+    results = experiment.run(conftest.exec_func, num_samples, num_workers, verbose=False)
     assert len(results) == len(experiment.config_iterator)
     for trial_id, trial_results in results.items():
         assert len(trial_results) == num_samples
